BellConfig class

Constructors

BellConfig({required int color, required int duration, required String animation})
const

Properties

animation String
final
color int
final
duration int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? color, int? duration, String? animation}) BellConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited