CursorConfig class

Constructors

CursorConfig({required int blinkInterval, int defaultShape = 0, bool defaultBlinking = false, int blinkTimeout = 5})
const

Properties

blinkInterval int
final
blinkTimeout int
final
defaultBlinking bool
final
defaultShape int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? blinkInterval, int? defaultShape, bool? defaultBlinking, int? blinkTimeout}) CursorConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited