ImeConfig class

Constructors

ImeConfig({required int preeditBg, required int preeditFg, required bool underline})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
preeditBg int
Background color for the preedit overlay (packed RGB; alpha is forced to full).
final
preeditFg int
Foreground color for the preedit overlay (packed RGB; alpha is forced to full).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underline bool
final

Methods

copyWith({int? preeditBg, int? preeditFg, bool? underline}) ImeConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited