ShellConfig class

Shell spawn configuration. program=null → $SHELL fallback (current behavior).

Constructors

ShellConfig({String? program, List<String> args = const [], String? workingDirectory, Map<String, String> env = const {}})
const

Properties

args List<String>
final
env Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
program String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory String?
final

Methods

copyWith({String? program, List<String>? args, String? workingDirectory, Map<String, String>? env}) ShellConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited