TerminalColors class

Constructors

TerminalColors({required int background, required int foreground, required int selection, required List<int> ansi, required int searchMatchBg, required int searchMatchFg, required int searchFocusedBg, required int searchFocusedFg, required int hintStartFg, required int hintStartBg, int? cursorText, int? cursorBody})
const

Properties

ansi List<int>
final
background int
final
cursorBody int?
final
cursorText int?
final
foreground int
final
hashCode int
The hash code for this object.
no setterinherited
hintStartBg int
final
hintStartFg int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchFocusedBg int
final
searchFocusedFg int
final
searchMatchBg int
final
searchMatchFg int
final
selection int
final

Methods

copyWith({int? background, int? foreground, int? selection, List<int>? ansi, int? searchMatchBg, int? searchMatchFg, int? searchFocusedBg, int? searchFocusedFg, int? hintStartFg, int? hintStartBg, int? cursorText, int? cursorBody}) TerminalColors
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited