TerminalSearchOptions class

Options for terminal buffer search.

Defaults match the Rust engine / GNOME Terminal-style find: case-insensitive, not whole-word, regex enabled, wrap around.

Constructors

TerminalSearchOptions({bool caseSensitive = false, bool wholeWord = false, bool regex = true, bool wrap = true})
const

Properties

caseSensitive bool
final
hashCode int
The hash code for this object.
no setterinherited
regex bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wholeWord bool
final
wrap bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited