TerminalScrollLatencySample class

One completed scheduleWrite → paint/present sample (microseconds).

Annotations

Constructors

TerminalScrollLatencySample({required int startUs, required int stopUs})
const

Properties

elapsedUs int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startUs int
final
stopUs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited