TerminalScrollTrace class

Scroll pipeline tracing. Enable any of:

  • FLUTTER_ALACRITTY_SCROLL_TRACE=true (runtime env var, desktop)
  • flutter run --dart-define=TERMINAL_SCROLL_TRACE=true
  • TerminalScrollTrace.enabled = true in host main()

Note: bool.fromEnvironment only accepts the literal strings "true" / "false"--dart-define=TERMINAL_SCROLL_TRACE=1 silently stays off.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

active bool
no setter
enabled bool
getter/setter pair

Static Methods

log(String component, String message) → void
pos({required int displayOffset, required double scrollFraction, required int historySize}) String