KeyBinding class

A parsed key binding: a Flutter activator + the Intent it triggers.

Constructors

KeyBinding(ShortcutActivator activator, Intent intent, {String mode = ''})
const

Properties

activator ShortcutActivator
final
hashCode int
The hash code for this object.
no setterinherited
intent Intent
final
mode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited