consumeAfterSend method
void
consumeAfterSend()
Auto-off after an effective send that consumed the latch.
Implementation
void consumeAfterSend() => clear();
Auto-off after an effective send that consumed the latch.
void consumeAfterSend() => clear();