input/paste library

Functions

pasteBytes(String text, {required int modeFlags}) Uint8List
Encodes pasted text for the PTY. In bracketed-paste mode the text is wrapped in ESC[200~ … ESC[201~ with all \x1b (ESC) and \x03 (Ctrl+C) stripped — matches alacritty event.rs:paste. Stripping ESC prevents any embedded escape sequence (incl. the end-marker \x1b[201~) from breaking out of the bracket and from being interpreted as a SGR / cursor command by the receiving program. Stripping \x03 works around shells that incorrectly terminate bracketed paste on Ctrl+C.