FlutterPtyBackend class

Implemented types

Constructors

FlutterPtyBackend({int rows = 24, int columns = 80, ShellConfig shell = const ShellConfig()})

Properties

exitCode Future<int>
Completes with the child process's exit code when it terminates.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
output Stream<Uint8List>
Bytes produced by the child process (shell stdout/stderr).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

kill() → void
Terminate the child and release resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize(int rows, int columns) → void
Tell the child the new window size. Order is (rows, columns).
override
toString() String
A string representation of this object.
inherited
write(Uint8List data) → void
Send bytes to the child process (stdin).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited