render/box_drawing library
Classes
Functions
-
boxOps(
int cp, Rect cell, double lineWidth) → List< BoxOp> -
Returns the draw ops for
cpwithincell. Empty ifcpis not handled programmatically (caller falls back to the font glyph). -
isBoxDrawing(
int cp) → bool -
paintBoxGlyph(
Canvas canvas, Rect cell, int cp, Color fg, double lineWidth) → bool -
Renders
cp's ops intocellwithfg. No-op (returns false) ifcphas no programmatic ops, so the caller can fall back to the font glyph.