contentHeight property
Glyph line-box height before font.offset Y. Strut / paragraph layout
must use this — offset grows the cell around the glyph, not the strut.
Implementation
final double contentHeight;
Glyph line-box height before font.offset Y. Strut / paragraph layout
must use this — offset grows the cell around the glyph, not the strut.
final double contentHeight;