dispose method
void
dispose()
Clears the cached paragraphs. Call before rebuilding the cache with new font metrics (e.g. on font-zoom).
Implementation
void dispose() {
_cache.clear();
_buildsThisFrame = 0;
}
Clears the cached paragraphs. Call before rebuilding the cache with new font metrics (e.g. on font-zoom).
void dispose() {
_cache.clear();
_buildsThisFrame = 0;
}