glyphOffsetX property
Shift applied when drawing paragraphs (alacritty font.glyph_offset).
Stored here so the painter can read it on the drawParagraph fallback path.
Implementation
final double glyphOffsetX;
Shift applied when drawing paragraphs (alacritty font.glyph_offset).
Stored here so the painter can read it on the drawParagraph fallback path.
final double glyphOffsetX;