maxBuildsPerFrame property
Caps synchronous paragraph layout per frame so first paint cannot freeze the UI.
Implementation
final int maxBuildsPerFrame;
Caps synchronous paragraph layout per frame so first paint cannot freeze the UI.
final int maxBuildsPerFrame;