RasterPresentSurface class
Holds the retained ui.Image uploaded from Rust RGBA frames.
This is the MVP "Rust raster present" path — not a Flutter external Texture. Cursor stays on CursorPainter above this image.
- Inheritance
-
- Object
- ChangeNotifier
- RasterPresentSurface
Constructors
Properties
- generation → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- image → Image?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
present(
RasterPresentFrame frame) → Future< void> -
Decode
frame.rgbainto a retained image (replaces the previous one). -
presentImageForTest(
Image image) → void - Synchronous present for tests that inject a pre-decoded image.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited