SearchColors class

Constructors

SearchColors({required int matchBg, required int matchFg, required int focusedBg, required int focusedFg})
const

Properties

focusedBg int
final
focusedFg int
final
hashCode int
The hash code for this object.
no setterinherited
matchBg int
final
matchFg int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited