onViewportResize property
Fired after engine is resized to match the view's cell grid (font zoom
or layout). Hosts should resize the PTY to the same (columns, rows).
Implementation
final void Function(int columns, int rows)? onViewportResize;
Fired after engine is resized to match the view's cell grid (font zoom
or layout). Hosts should resize the PTY to the same (columns, rows).
final void Function(int columns, int rows)? onViewportResize;