cell property
Measured cell dimensions at the current font size + DPR. Sub-pixel precision; must match what the painter uses.
Implementation
final CellMetrics cell;
Measured cell dimensions at the current font size + DPR. Sub-pixel precision; must match what the painter uses.
final CellMetrics cell;