FontConfig class
Constructors
-
FontConfig({required String family, required List<
String> fallback, required double size, required double lineHeight, FontStyleConfig? bold, FontStyleConfig? italic, FontStyleConfig? boldItalic, double offsetX = 0, double offsetY = 0, double glyphOffsetX = 0, double glyphOffsetY = 0}) -
const
Properties
- bold → FontStyleConfig?
-
final
- boldItalic → FontStyleConfig?
-
final
-
fallback
→ List<
String> -
final
- family → String
-
final
- glyphOffsetX → double
-
Shift of the glyph bitmap inside the cell (alacritty
font.glyph_offset).final - glyphOffsetY → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- italic → FontStyleConfig?
-
final
- lineHeight → double
-
final
- offsetX → double
-
Extra pixels added to measured cell width/height (alacritty
font.offset).final - offsetY → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
Methods
-
copyWith(
{String? family, List< String> ? fallback, double? size, double? lineHeight, FontStyleConfig? bold, FontStyleConfig? italic, FontStyleConfig? boldItalic, double? offsetX, double? offsetY, double? glyphOffsetX, double? glyphOffsetY}) → FontConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited