TerminalColors class
Constructors
-
TerminalColors({required int background, required int foreground, required int selection, required List<int> ansi, required int searchMatchBg, required int searchMatchFg, required int searchFocusedBg, required int searchFocusedFg, required int hintStartFg, required int hintStartBg, int? cursorText, int? cursorBody})
-
const
Methods
-
copyWith({int? background, int? foreground, int? selection, List<int>? ansi, int? searchMatchBg, int? searchMatchFg, int? searchFocusedBg, int? searchFocusedFg, int? hintStartFg, int? hintStartBg, int? cursorText, int? cursorBody})
→ TerminalColors
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited