WindowConfig class
Constructors
- WindowConfig({WindowPadding padding = const WindowPadding(0, 0), double opacity = 1.0, String decorations = 'full'})
-
const
Properties
- decorations → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opacity → double
-
final
- padding → WindowPadding
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{WindowPadding? padding, double? opacity, String? decorations}) → WindowConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited