TerminalScrollTrace class

Scroll pipeline tracing. Enable any of:

  • flutter run --dart-define=TERMINAL_SCROLL_TRACE=1
  • TerminalScrollTrace.enabled = true in host main()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
getter/setter pair

Static Methods

log(String component, String message) → void
pos({required int displayOffset, required double scrollFraction, required int historySize}) String