RasterPresentBinding class abstract
Optional Rust-raster present surface on an EngineBinding.
Implemented by FrbEngineBinding and test fakes that exercise the raster
hot path. Kept off EngineBinding so existing implements fakes stay small.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
advanceAndTakeRasterPresent(
Uint8List bytes) → Future< RasterPresentFrame> -
fullRasterPresent(
) → RasterPresentFrame -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scrollLinesRaster(
int delta) → Future< RasterPresentFrame> -
scrollPixelsRaster(
double deltaPx) → Future< RasterPresentFrame> -
scrollToBottomRaster(
) → Future< RasterPresentFrame> -
scrollToOffsetRaster(
double offsetLines) → Future< RasterPresentFrame> -
scrollToTopRaster(
) → Future< RasterPresentFrame> -
takeRasterPresent(
) → RasterPresentFrame -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited