title property

ValueNotifier<String>? title
final

Optional external title notifier. When null the example creates and owns its own (and disposes it). Pass one when the host wants to observe title changes (e.g. for window decorations or tests).

Implementation

final ValueNotifier<String>? title;