TerminalKeyInjector class
Injects accessory-key text and logical keys into the PTY, merging ModifierLatch state into terminal byte sequences.
Constructors
- TerminalKeyInjector({required ModifierLatch latch, required int modeFlags(), required void write(Uint8List bytes), required void resetComposing(), required bool isComposing()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComposing → bool Function()
-
final
- latch → ModifierLatch
-
final
- modeFlags → int Function()
-
final
- resetComposing → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- write → void Function(Uint8List bytes)
-
final
Methods
-
injectKey(
LogicalKeyboardKey key) → void -
injectText(
String text) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited