TuiWheelEvent class
Minimal wheel input for resolveTuiWheelReportCount.
Constructors
- TuiWheelEvent({required double deltaY, TuiWheelDeltaMode deltaMode = TuiWheelDeltaMode.pixel, double? timeStampMs, double? legacyWheelDeltaY})
-
const
Properties
- deltaMode → TuiWheelDeltaMode
-
final
- deltaY → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legacyWheelDeltaY → double?
-
Legacy
wheelDeltaY/wheelDelta(IE/Chrome), when available.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeStampMs → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited