shouldWatchForegroundProcess function
Whether FlutterPtyBackend should expose a foreground listenable.
Windows and platforms that return null from the underlying PTY skip
polling so hosts see null rather than a stuck false notifier.
Implementation
@visibleForTesting
bool shouldWatchForegroundProcess({
required bool isWindows,
required bool? initialForegroundRunning,
}) =>
!isWindows && initialForegroundRunning != null;