GridUpdate class
A render update: either a full replace or a set of changed lines.
Constructors
-
GridUpdate({required bool full, required int rows, required int columns, required List<
LineCells> lines, required int cursorRow, required int cursorCol, required bool cursorVisible, int cursorShape = 0, bool cursorBlinking = false, int modeFlags = 0, int displayOffset = 0, int defaultFg = 0xD8D8D8, int defaultBg = 0x181818, int cursorColor = 0xFF000000, double scrollFraction = 0.0, LineCells? overscan})
Properties
- columns → int
-
final
- cursorBlinking → bool
-
final
- cursorCol → int
-
final
- cursorColor → int
-
final
- cursorRow → int
-
final
- cursorShape → int
-
final
- cursorVisible → bool
-
final
- defaultBg → int
-
final
- defaultFg → int
-
final
- displayOffset → int
-
final
- full → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
LineCells> -
final
- modeFlags → int
-
final
- overscan → LineCells?
-
The line directly above the viewport top, used to fill the sliver revealed
when scrollFraction > 0. Present only on full updates (null on partial
damage, where the fraction is always 0).
final
- rows → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollFraction → double
-
Sub-cell scroll position in [0.0, 1.0). See TerminalGridView.scrollFraction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited