overscan property
The line directly above the viewport top, used to fill the sliver revealed when scrollFraction > 0. Present only on full updates (null on partial damage, where the fraction is always 0).
Implementation
final LineCells? overscan;
The line directly above the viewport top, used to fill the sliver revealed when scrollFraction > 0. Present only on full updates (null on partial damage, where the fraction is always 0).
final LineCells? overscan;