LineCells class
One line's cells (native types — decoupled from FRB so MirrorGrid is unit-testable without the native lib).
Constructors
Properties
- bg → Int32List
-
final
- codepoints → Int32List
-
final
- fg → Int32List
-
final
- flags → Uint16List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hyperlinkId → Int32List
-
final
- line → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited